@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.01_16';
+$VERSION = '2.01_18';
 
 bootstrap DBD::mSQL $VERSION;
 
@@ -261,6 +261,10 @@ sub admin {
 			   '_admin_internal');
 }
 
+sub _SelectDB ($$) {
+    die "_SelectDB is removed from this module; use DBI->connect instead.";
+}
+
 
 package DBD::mSQL::st; # ====== STATEMENT ======
 use strict;
