@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.01_14';
+$VERSION = '2.01_18';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -261,6 +261,10 @@ sub admin {
 			   '_admin_internal');
 }
 
+sub _SelectDB ($$) {
+    die "_SelectDB is removed from this module; use DBI->connect instead.";
+}
+
 
 package DBD::mysql::st; # ====== STATEMENT ======
 use strict;
@@ -294,13 +298,18 @@ Interface (DBI)
 
     use DBI;
 
-    $dbh = DBI->connect("DBI:mSQL:$database:$hostname:$port",
-			undef, undef);
+    $driver = "mSQL"; # or "mSQL1";
+    $dsn = "DBI:$driver:database=$database;host=$hostname;port=$port";
+
+    $dbh = DBI->connect($dsn,	undef, undef);
 
         or
 
-    $dbh = DBI->connect("DBI:mysql:$database:$hostname:$port",
-			$user, $password);
+    $driver = "mysql";
+    $dsn = "DBI:$driver:database=$database;host=$hostname;port=$port";
+
+    $dbh = DBI->connect($dsn, $user, $password);
+
 
     @databases = DBD::mysql::dr->func($host, $port, '_ListDBs');
     @tables = $dbh->func( '_ListTables' );
@@ -354,9 +363,10 @@ of the I<Msql-Mysql-modules> package.
 
     use DBI;
 
-    $dsn = "DBI:mSQL:$database";
-    $dsn = "DBI:mSQL:database=$database;host=$hostname";
-    $dsn = "DBI:mSQL:database=$database;host=$hostname;port=$port";
+    $driver = "mSQL";  #  or "mSQL1"
+    $dsn = "DBI:$driver:$database";
+    $dsn = "DBI:$driver:database=$database;host=$hostname";
+    $dsn = "DBI:$driver:database=$database;host=$hostname;port=$port";
 
     $dbh = DBI->connect($dsn, undef, undef);
 
