@@ -124,7 +124,7 @@ void do_warn(SV* h, int rc, char* what) {
  **************************************************************************/
 
 int MyConnect(dbh_t *sock, char* host, char* port, char* user,
-	      char* password) {
+	      char* password, char* dbname) {
     int portNr;
 
     if (host && !*host) host = NULL;
@@ -161,15 +161,18 @@ int MyConnect(dbh_t *sock, char* host, char* port, char* user,
 	    mysql_port = oldPort;
 	}
 	return result;
-#else
-#if defined(MYSQL_VERSION_ID)  &&  MYSQL_VERSION_ID >= 032115
+#elif defined(MYSQL_VERSION_ID)  &&  (MYSQL_VERSION_ID >= 32200)
+	mysql_init(*sock);
+	return mysql_real_connect(*sock, host, user, password, dbname,
+				  portNr, NULL, 0) ?
+	    TRUE : FALSE;
+#elif defined(MYSQL_VERSION_ID)  &&  (MYSQL_VERSION_ID >= 32115)
 	return mysql_real_connect(*sock, host, user, password, portNr, NULL,
 				  0) ?
 	    TRUE : FALSE;
 #else
 	return mysql_real_connect(*sock, host, user, password, portNr, NULL) ?
 	    TRUE : FALSE;
-#endif
 #endif
     }
 #else
@@ -274,7 +277,12 @@ static int _MyLogin(imp_dbh_t *imp_dbh) {
     imp_dbh->svsock = &imp_dbh->mysql;
 #endif
 
-    if (!MyConnect(&imp_dbh->svsock, host, port, user, password)) {
+#if defined(DBD_MYSQL)  &&  (MYSQL_VERSION_ID >= 32200)
+    if (!MyConnect(&imp_dbh->svsock, host, port, user, password, dbname)) {
+        return FALSE;
+    }
+#else
+    if (!MyConnect(&imp_dbh->svsock, host, port, user, password, NULL)) {
         return FALSE;
     }
 
@@ -282,6 +290,8 @@ static int _MyLogin(imp_dbh_t *imp_dbh) {
         MyClose(imp_dbh->svsock);
 	return FALSE;
     }
+#endif
+
     return TRUE;
 }
 
@@ -406,6 +416,9 @@ int dbd_db_disconnect(SV* dbh, imp_dbh_t* imp_dbh) {
  **************************************************************************/
 
 int dbd_discon_all (SV *drh, imp_drh_t *imp_drh) {
+#if defined(dTHR)
+    dTHR;
+#endif
     /* The disconnect_all concept is flawed and needs more work */
     if (!dirty && !SvTRUE(perl_get_sv("DBI::PERL_ENDING",0))) {
 	sv_setiv(DBIc_ERR(imp_drh), (IV)1);
@@ -551,13 +564,7 @@ SV* dbd_db_FETCH_attrib(SV* dbh, imp_dbh_t* imp_dbh, SV* keysv) {
 #endif
       case 'p':
 	if (kl == 9  &&  strEQ(key, "protoinfo")) {
-#ifdef DBD_MYSQL
-	    char* protoinfo = MyGetProtoInfo(imp_dbh->svsock);
-	    return protoinfo ?
-	        sv_2mortal(newSVpv(protoinfo, strlen(protoinfo))) : &sv_undef;
-#else
 	    return sv_2mortal(newSViv(MyGetProtoInfo(imp_dbh->svsock)));
-#endif
 	}
 	break;
       case 's':
@@ -576,7 +583,7 @@ SV* dbd_db_FETCH_attrib(SV* dbh, imp_dbh_t* imp_dbh, SV* keysv) {
 	    char* stats = mysql_stat(imp_dbh->svsock);
 	    return stats ?
 	        sv_2mortal(newSVpv(stats, strlen(stats))) : &sv_undef;
-#elif defined(DBD_MSQL)
+#elif defined(DBD_MSQL) && defined(IDX_TYPE)
 	    return sv_2mortal(newSViv(msqlGetServerStats(imp_dbh->svsock)));
 #endif
 	}
@@ -730,7 +737,7 @@ int dbd_st_internal_execute(SV* h, SV* statement, SV* attribs, int numParams,
 	    }
 
 	    return 0;
-#if defined(DBD_MSQL)
+#if defined(DBD_MSQL)  &&  defined(IDX_TYPE)
 	} else if (tolower(sbuf[4]) == 'i'
 		   &&  tolower(sbuf[5]) == 'n'
 		   &&  tolower(sbuf[6]) == 'd'
@@ -839,6 +846,10 @@ int dbd_st_execute(SV* sth, imp_sth_t* imp_sth) {
      */
     for (i = 0;  i < AV_ATTRIB_LAST;  i++) {
 	if (imp_sth->av_attr[i]) {
+#ifdef DEBUGGING_MEMORY_LEAK
+	    printf("Execute: Decrementing refcnt: old = %d\n",
+		   SvREFCNT(imp_sth->av_attr[i]));
+#endif
 	    SvREFCNT_dec(imp_sth->av_attr[i]);
 	}
 	imp_sth->av_attr[i] = Nullav;
@@ -960,10 +971,6 @@ AV* dbd_st_fetch(SV* sth, imp_sth_t* imp_sth) {
 	    STRLEN len = strlen(col);
 #endif
 	    if (ChopBlanks) {
-		while(len && isspace(*col)) {
-		    ++col;
-		    --len;
-		}
 		while(len && isspace(col[len-1])) {
 		    --len;
 		}
@@ -1042,6 +1049,10 @@ void dbd_st_destroy(SV* sth, imp_sth_t* imp_sth) {
      */
     for (i = 0;  i < AV_ATTRIB_LAST;  i++) {
 	if (imp_sth->av_attr[i]) {
+#ifdef DEBUGGING_MEMORY_LEAK
+	    printf("DESTROY: Decrementing refcnt: old = %d\n",
+		   SvREFCNT(imp_sth->av_attr[i]));
+#endif
 	    SvREFCNT_dec(imp_sth->av_attr[i]);
 	}
 	imp_sth->av_attr[i] = Nullav;
@@ -1282,14 +1293,16 @@ SV* dbd_st_FETCH_internal(SV* sth, int what, result_t res, int cacheit) {
 	 *  dbd_st_destroy and dbd_st_execute.
 	 */
 	if (cacheit) {
-	    imp_sth->av_attr[what] = (AV*) SvREFCNT_inc((SV*)av);
+	    imp_sth->av_attr[what] = av;
+	} else {
+	    return sv_2mortal(newRV_noinc((SV*)av));
 	}
     }
 
     if (av == Nullav) {
 	return &sv_undef;
     }
-    return sv_2mortal(newRV((SV*)av));
+    return sv_2mortal(newRV_inc((SV*)av));
 }
 
 
